==> speech-analytic-testing_1.3.0_database.tar.gz: database/mssql/procedures/GetEvaluationResultsFromAuditorEvaluationPlan.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan] (
	@Instance Varchar(50) = NULL,
    @EvaluationPlanId Varchar(50) = NULL,
    @InteractionId varchar(250) = NULL,
    @InteractionType varchar(50) = NULL,
    @AuditorId varchar(50) = NULL,
    @AgentId varchar(50) = NULL
)
AS
BEGIN
    SET NOCOUNT ON

	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA OBTENER LOS REGISTROS UNICOS QUE INSERTAREMOS EN LA TABLA EVALUATION_RESULT
	--  ORDENANDO POR SECTION Y PART
	;WITH CTE AS (
		SELECT TOP 1 IEP.[Instance],
						IEP.[IdEvaluationPlan],
						IEP.[IdInteraction],
						IEP.[IdAgent],
						IEP.[AgentName]
			FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
			WHERE IEP.[Instance] = @Instance
				AND IEP.[IdEvaluationPlan] = @EvaluationPlanId
				AND IEP.[IdInteraction] = @InteractionId 
				AND IEP.[InteractionType] = @InteractionType
				AND IEP.[IdAgent] = @AgentId
	)

    SELECT DISTINCT
         EF.Id										'EvaluationFormatId'				-- Id
        ,EF.Description								'EvaluationFormatDescription'		-- Titulo del reporte
        ,ER.Instance								'Instance'							-- Subtitulo del reporte
        ,ER.IdAgent									'AgentId'							-- Agente
        ,ER.IdAgent									'AgentDescription'					-- Agente
		,C.[AgentName]								'agentName'							-- NOMBRE DEL AGENTE
        ,CONCAT(U.Firstname, ' ', U.Lastname)		'CoordinatorFullName'				-- Coordinador
        ,AEP.IdAuditor								'AuditorId'							-- Auditor
        ,CONCAT(UA.Firstname, ' ',UA.Lastname)		'AuditorDescription'				-- Auditor
		,AEP.IdAuditor
        ,ER.IdCampaign								'CampaignDescription'				-- Campana
        ,ER.IdInteraction							'InteractionId'						-- Grabacion
        ,ER.InteractionType							'InteractionType'					-- Tipo interaccion
        ,ER.InteractionDateini						'InteractionDateIni'				-- Fecha inicio de la interaccion
		,ER.[InteractionDatefin]					'InteractionDateFin'				-- Fecha fin de la interaccion
        ,ER.InteractionAddress						'Contacto'							-- Telefono
        ,ER.EvaluationDate							'EvaluationDate'					-- Fecha monitoreo
        ,AEP.Score									'TotalScore'						-- Puntaje total
        ,G.Id										'GroupId'							-- Grupo
        ,G.Description								'Group'								-- Grupo
        ,SG.Id										'SubGroupId'						-- Subgrupo
        ,SG.Description								'SubGroup'							-- Subgrupo
        ,AB.Id										'AbilityId'							-- Habilidad
        ,AB.Title									'Ability'							-- Habilidad
		,AB.[Detail]								'AbilityDetail'						-- Habilidad
        ,ER.Comment									'Observacion'						-- Observacion de la habilidad
        ,ER.MaxAbilityScore							'Puntaje'							-- Puntaje
        ,ER.ScoreDescription						'Eval'								-- Eval
        ,ER.Qualification							'Nota'								-- Nota
		,ER.[OwnScore]								'ownScore'
		,ER.[InheritedScore]						'inheritedScore'
		,ER.[AbilityInnerScore]						'abilityInnerScore'
        ,ER.NotApplies								'NotApplies'
		,AB.[Distribute]							'distribute'
        ,ER.AbilityOrder							'Order'
        ,ER.Conditional                             'conditionalSelected'
    FROM [dbo].[EvaluationResult] ER (NOLOCK)
    JOIN [dbo].[EvaluationPlan] EP (NOLOCK) 
         ON (EP.[Instance]=ER.[Instance]
         AND EP.ID=ER.IdEvaluationPlan)
    INNER JOIN	[dbo].[EvaluationFormat] EF (NOLOCK)
	--LEFT JOIN [EvaluationFormat] EF (NOLOCK)
		ON (ER.Instance = EF.Instance 
			AND	ER.IdEvaluationFormat = EF.ID)
    LEFT JOIN [dbo].[User] U (NOLOCK)
		ON (EP.Instance = U.VCC
			AND EP.CreatedByUserId = U.ID)
    --INNER JOIN [User] UA (NOLOCK)
	LEFT JOIN [dbo].[User] UA (NOLOCK)
		ON (ER.Instance = UA.VCC 
			AND ER.IdEvaluator = UA.ID)
    --INNER JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
	LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
		ON (ER.IdEvaluationPlan	= AEP.IdEvaluationPlan
			AND ER.IdEvaluator = AEP.IdAuditor
			AND ER.IdInteraction = AEP.IdInteraction
			AND ER.InteractionType = AEP.InteractionType
			AND ER.IdAgent = AEP.IdAgent)
    LEFT JOIN [dbo].[Group] G (NOLOCK)
		ON (ER.Instance = G.Instance
			AND ER.IdGroup = G.ID)
    LEFT JOIN [SubGroup] SG (NOLOCK)
		ON (ER.Instance = SG.Instance 
			AND ER.IdSubGroup = SG.ID)
    LEFT JOIN [Ability] AB (NOLOCK)
		ON (ER.Instance = AB.Instance 
			AND ER.IdAbility = AB.ID)
	LEFT JOIN CTE C (NOLOCK) -- LA TABLA AGENT NO ES DETERMINANTE POR ESO SE AGREGA POR LEFT JOIN
		ON C.[Instance] = ER.[Instance]
			AND C.[IdInteraction] = ER.IdInteraction
			AND C.[IdAgent] = ER.[IdAgent]
    WHERE ER.Instance = @Instance
		AND ER.IdEvaluationPlan	= @EvaluationPlanId
		AND ER.IdInteraction = @InteractionId
		AND ER.InteractionType = @InteractionType
		--AND ER.IdEvaluator = @AuditorId
		AND ER.[IdAuditor] = @AuditorId
		AND ER.IdAgent = @AgentId
    ORDER BY ER.AbilityOrder ASC;

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_1.9.0_database.tar.gz: database/mssql/procedures/GetEvaluationResultsFromAuditorEvaluationPlan.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan] (
	@Instance Varchar(50) = NULL,
    @EvaluationPlanId Varchar(50) = NULL,
    @InteractionId varchar(250) = NULL,
    @InteractionType varchar(50) = NULL,
    @AuditorId varchar(50) = NULL,
    @AgentId varchar(50) = NULL
)
AS
BEGIN
    SET NOCOUNT ON

	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA OBTENER LOS REGISTROS UNICOS QUE INSERTAREMOS EN LA TABLA EVALUATION_RESULT
	--  ORDENANDO POR SECTION Y PART
	;WITH CTE AS (
		SELECT TOP 1 IEP.[Instance],
						IEP.[IdEvaluationPlan],
						IEP.[IdInteraction],
						IEP.[IdAgent],
						IEP.[AgentName]
			FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
			WHERE IEP.[Instance] = @Instance
				AND IEP.[IdEvaluationPlan] = @EvaluationPlanId
				AND IEP.[IdInteraction] = @InteractionId 
				AND IEP.[InteractionType] = @InteractionType
				AND IEP.[IdAgent] = @AgentId
	)

    SELECT DISTINCT
         EF.Id										'EvaluationFormatId'				-- Id
        ,EF.Description								'EvaluationFormatDescription'		-- Titulo del reporte
        ,ER.Instance								'Instance'							-- Subtitulo del reporte
        ,ER.IdAgent									'AgentId'							-- Agente
        ,ER.IdAgent									'AgentDescription'					-- Agente
		,C.[AgentName]								'agentName'							-- NOMBRE DEL AGENTE
        ,CONCAT(U.Firstname, ' ', U.Lastname)		'CoordinatorFullName'				-- Coordinador
        ,AEP.IdAuditor								'AuditorId'							-- Auditor
        ,CONCAT(UA.Firstname, ' ',UA.Lastname)		'AuditorDescription'				-- Auditor
		,AEP.IdAuditor
        ,ER.IdCampaign								'CampaignDescription'				-- Campana
        ,ER.IdInteraction							'InteractionId'						-- Grabacion
        ,ER.InteractionType							'InteractionType'					-- Tipo interaccion
        ,ER.InteractionDateini						'InteractionDateIni'				-- Fecha inicio de la interaccion
		,ER.[InteractionDatefin]					'InteractionDateFin'				-- Fecha fin de la interaccion
        ,ER.InteractionAddress						'Contacto'							-- Telefono
        ,ER.EvaluationDate							'EvaluationDate'					-- Fecha monitoreo
        ,AEP.Score									'TotalScore'						-- Puntaje total
        ,G.Id										'GroupId'							-- Grupo
        ,G.Description								'Group'								-- Grupo
        ,SG.Id										'SubGroupId'						-- Subgrupo
        ,SG.Description								'SubGroup'							-- Subgrupo
        ,AB.Id										'AbilityId'							-- Habilidad
        ,AB.Title									'Ability'							-- Habilidad
		,AB.[Detail]								'AbilityDetail'						-- Habilidad
        ,ER.Comment									'Observacion'						-- Observacion de la habilidad
        ,ER.MaxAbilityScore							'Puntaje'							-- Puntaje
        ,ER.ScoreDescription						'Eval'								-- Eval
        ,ER.Qualification							'Nota'								-- Nota
		,ER.[OwnScore]								'ownScore'
		,ER.[InheritedScore]						'inheritedScore'
		,ER.[AbilityInnerScore]						'abilityInnerScore'
        ,ER.NotApplies								'NotApplies'
		,AB.[Distribute]							'distribute'
        ,ER.AbilityOrder							'Order'
        ,ER.Conditional                             'conditionalSelected'
    FROM [dbo].[EvaluationResult] ER (NOLOCK)
    JOIN [dbo].[EvaluationPlan] EP (NOLOCK) 
         ON (EP.[Instance]=ER.[Instance]
         AND EP.ID=ER.IdEvaluationPlan)
    INNER JOIN	[dbo].[HistoricEvaluationFormat] EF (NOLOCK)
	--LEFT JOIN [EvaluationFormat] EF (NOLOCK)
		ON (ER.Instance = EF.VCC 
			AND	ER.IdEvaluationFormat = EF.ID)
    LEFT JOIN [dbo].[User] U (NOLOCK)
		ON (EP.Instance = U.VCC
			AND EP.CreatedByUserId = U.ID)
    --INNER JOIN [User] UA (NOLOCK)
	LEFT JOIN [dbo].[User] UA (NOLOCK)
		ON (ER.Instance = UA.VCC 
			AND ER.IdEvaluator = UA.ID)
    --INNER JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
	LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
		ON (ER.IdEvaluationPlan	= AEP.IdEvaluationPlan
			AND ER.IdEvaluator = AEP.IdAuditor
			AND ER.IdInteraction = AEP.IdInteraction
			AND ER.InteractionType = AEP.InteractionType
			AND ER.IdAgent = AEP.IdAgent)
    LEFT JOIN [dbo].[HistoricGroup] G (NOLOCK)
		ON (ER.Instance = G.VCC
			AND ER.IdGroup = G.ID)
    LEFT JOIN [HistoricSubGroup] SG (NOLOCK)
		ON (ER.Instance = SG.VCC 
			AND ER.IdSubGroup = SG.ID)
    LEFT JOIN [HistoricAbility] AB (NOLOCK)
		ON (ER.Instance = AB.VCC 
			AND ER.IdAbility = AB.ID)
	LEFT JOIN CTE C (NOLOCK) -- LA TABLA AGENT NO ES DETERMINANTE POR ESO SE AGREGA POR LEFT JOIN
		ON C.[Instance] = ER.[Instance]
			AND C.[IdInteraction] = ER.IdInteraction
			AND C.[IdAgent] = ER.[IdAgent]
    WHERE ER.Instance = @Instance
		AND ER.IdEvaluationPlan	= @EvaluationPlanId
		AND ER.IdInteraction = @InteractionId
		AND ER.InteractionType = @InteractionType
		--AND ER.IdEvaluator = @AuditorId
		AND ER.[IdAuditor] = @AuditorId
		AND ER.IdAgent = @AgentId
    ORDER BY ER.AbilityOrder ASC;

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
